@@ -3,10 +3,10 @@
 Printing a list of Pygments (Token, text) tuples,
 or an output of a Pygments lexer.
 """
-from __future__ import unicode_literals
+
 import pygments
-from pygments.token import Token
 from pygments.lexers.python import PythonLexer
+from pygments.token import Token
 
 from prompt_toolkit import print_formatted_text
 from prompt_toolkit.formatted_text import PygmentsTokens
@@ -16,13 +16,13 @@ from prompt_toolkit.styles import Style
 def main():
     # Printing a manually constructed list of (Token, text) tuples.
     text = [
-        (Token.Keyword, 'print'),
-        (Token.Punctuation, '('),
+        (Token.Keyword, "print"),
+        (Token.Punctuation, "("),
         (Token.Literal.String.Double, '"'),
-        (Token.Literal.String.Double, 'hello'),
+        (Token.Literal.String.Double, "hello"),
         (Token.Literal.String.Double, '"'),
-        (Token.Punctuation, ')'),
-        (Token.Text, '\n'),
+        (Token.Punctuation, ")"),
+        (Token.Text, "\n"),
     ]
 
     print_formatted_text(PygmentsTokens(text))
@@ -32,12 +32,14 @@ def main():
     print_formatted_text(PygmentsTokens(tokens))
 
     # With a custom style.
-    style = Style.from_dict({
-        'pygments.keyword': 'underline',
-        'pygments.literal.string': 'bg:#00ff00 #ffffff',
-    })
+    style = Style.from_dict(
+        {
+            "pygments.keyword": "underline",
+            "pygments.literal.string": "bg:#00ff00 #ffffff",
+        }
+    )
     print_formatted_text(PygmentsTokens(tokens), style=style)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
