@@ -4,13 +4,14 @@ Styled similar to tqdm, another progress bar implementation in Python.
 
 See: https://github.com/noamraph/tqdm
 """
+
 import time
 
 from prompt_toolkit.shortcuts import ProgressBar
 from prompt_toolkit.shortcuts.progress_bar import formatters
 from prompt_toolkit.styles import Style
 
-style = Style.from_dict({"bar-a": "reverse",})
+style = Style.from_dict({"bar-a": "reverse"})
 
 
 def main():
