@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from string import Formatter
-from typing import Generator, List, Optional
+from typing import Generator
 
 from prompt_toolkit.output.vt100 import BG_ANSI_COLORS, FG_ANSI_COLORS
 from prompt_toolkit.output.vt100 import _256_colors as _256_colors_table
@@ -37,6 +37,7 @@ class ANSI:
         self._color: str | None = None
         self._bgcolor: str | None = None
         self._bold = False
+        self._dim = False
         self._underline = False
         self._strike = False
         self._italic = False
@@ -153,8 +154,8 @@ class ANSI:
                 self._bgcolor = _bg_colors[attr]
             elif attr == 1:
                 self._bold = True
-            # elif attr == 2:
-            #   self._faint = True
+            elif attr == 2:
+                self._dim = True
             elif attr == 3:
                 self._italic = True
             elif attr == 4:
@@ -171,6 +172,7 @@ class ANSI:
                 self._strike = True
             elif attr == 22:
                 self._bold = False  # Normal intensity
+                self._dim = False
             elif attr == 23:
                 self._italic = False
             elif attr == 24:
@@ -188,6 +190,7 @@ class ANSI:
                 self._color = None
                 self._bgcolor = None
                 self._bold = False
+                self._dim = False
                 self._underline = False
                 self._strike = False
                 self._italic = False
@@ -210,10 +213,8 @@ class ANSI:
                 # True colors.
                 if n == 2 and len(attrs) >= 3:
                     try:
-                        color_str = "#{:02x}{:02x}{:02x}".format(
-                            attrs.pop(),
-                            attrs.pop(),
-                            attrs.pop(),
+                        color_str = (
+                            f"#{attrs.pop():02x}{attrs.pop():02x}{attrs.pop():02x}"
                         )
                     except IndexError:
                         pass
@@ -234,6 +235,8 @@ class ANSI:
             result.append("bg:" + self._bgcolor)
         if self._bold:
             result.append("bold")
+        if self._dim:
+            result.append("dim")
         if self._underline:
             result.append("underline")
         if self._strike:
